@@ -20,7 +20,11 @@ The Net::SSLeay::PEM class of L<SPVM> has methods to manipulate PEM.
 
 =head2 read_bio_X509
 
-  static method read_bio_X509 : Net::SSLeay::X509 ($bp : Net::SSLeay::BIO);
+C<static method read_bio_X509 : Net::SSLeay::X509 ($bp : L<Net::SSLeay::BIO|SPVM::Net::SSLeay::BIO>);>
+
+=head2 read_bio_X509_CRL
+
+C<static method read_bio_X509_CRL : Net::SSLeay::X509_CRL ($bp : L<Net::SSLeay::BIO|SPVM::Net::SSLeay::BIO>);>
 
 =head1 Copyright & License
 
