@@ -18,6 +18,10 @@ The Net::SSLeay::SSL_METHOD class of L<SPVM> has methods for SSL/TLS methods.
 
 =head1 Class Methods
 
+=head2 SSLv23_method
+
+  static method SSLv23_method : Net::SSLeay::SSL_METHOD ();
+
 =head2 SSLv23_client_method
 
   static method SSLv23_client_method : Net::SSLeay::SSL_METHOD ();
@@ -26,6 +30,10 @@ The Net::SSLeay::SSL_METHOD class of L<SPVM> has methods for SSL/TLS methods.
 
   static method SSLv23_server_method : Net::SSLeay::SSL_METHOD ();
 
+=head2 TLS_method
+
+  static method TLS_method : Net::SSLeay::SSL_METHOD ();
+
 =head2 TLS_client_method
 
   static method TLS_client_method : Net::SSLeay::SSL_METHOD ();
