@@ -54,3 +54,17 @@ int32_t SPVM__Net__SSLeay__X509_VERIFY_PARAM__set1_host(SPVM_ENV* env, SPVM_VALU
   
   return 0;
 }
+
+int32_t SPVM__Net__SSLeay__X509_VERIFY_PARAM__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
+  int32_t error_id = 0;
+  
+  void* obj_self = stack[0].oval;
+  
+  X509_VERIFY_PARAM* x509_verify_param = env->get_pointer(env, stack, obj_self);
+  
+  if (!env->no_free(env, stack, obj_self)) {
+    X509_VERIFY_PARAM_free(x509_verify_param);
+  }
+  
+  return 0;
+}
